'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PDFJS = require('pdfjs-dist');
var pdfjsWorker = _interopDefault(require('pdfjs-dist/build/pdf.worker.entry'));

PDFJS.GlobalWorkerOptions.workerSrc = pdfjsWorker;
/**
 * 渲染pdf文件的指定页到画板
 * @param pdfViewerDom 承载pdf画板的dom容器
 * @param pdfDoc pdf文件
 * @param pageNum 需要渲染的页码
 * @param scale 缩放比例
 */

function renderPdfOnePage(pdfViewerDom, pdfDoc, pageNum, scale) {
  // 创建画布
  var canvas = document.createElement('canvas');
  pdfViewerDom.appendChild(canvas); // 获取2d上下文

  var context = canvas.getContext('2d');
  pdfDoc.getPage(pageNum).then(function (page) {
    // 获取当前pdf页内容, 并设置缩放
    var viewport = page.getViewport({
      scale: scale
    }); // @ts-ignore

    var realCanvas = context.canvas;
    realCanvas.width = viewport.width;
    realCanvas.height = viewport.height; // 将pdf当前页内容画到2d画板中
    // @ts-ignore

    page.render({
      canvasContext: context,
      viewport: viewport
    });
  });
}
/**
 * 完整显示pdf内容
 * @param props
 * @constructor
 */

var PdfViewer = function PdfViewer(props) {
  var pdfUrl = props.pdfUrl,
      scale = props.scale; // 存放pdf文档

  var pdfDocRef = React.useRef(null); // 存放承载pdf画布的dom容器

  var pdfViewerRef = React.useRef(null);
  /**
   * 渲染pdf的画布
   * @param pdfViewerDom 承载pdf画布的dom容器
   * @param pdfDoc pdf文档
   * @param scale 缩放比例
   */

  function renderPdfCanvas(pdfViewerDom, pdfDoc, scale) {
    // 清除原来的pdf画布
    pdfViewerDom.innerHTML = ''; // 获取总页数

    var totalPage = pdfDoc.numPages; // 获取显示容器

    for (var i = 1; i <= totalPage; i++) {
      // 循环处理pdf的每页
      renderPdfOnePage(pdfViewerDom, pdfDoc, i, scale);
    }
  }

  React.useLayoutEffect(function () {
    if (pdfUrl) {
      // 获取pdf文件
      var pdfLoadingTask = PDFJS.getDocument(pdfUrl);
      pdfLoadingTask.promise.then(function (pdfDoc) {
        var pdfViewerDom = pdfViewerRef.current;

        if (pdfDoc && pdfViewerDom) {
          // 缓存pdf内容
          pdfDocRef.current = pdfDoc; // @ts-ignore

          renderPdfCanvas(pdfViewerDom, pdfDoc, scale);
        }
      });
    }
  }, [pdfUrl]);
  React.useLayoutEffect(function () {
    var pdfDoc = pdfDocRef.current;
    var pdfViewerDom = pdfViewerRef.current;

    if (pdfDoc && pdfViewerDom) {
      // @ts-ignore
      renderPdfCanvas(pdfViewerDom, pdfDoc, scale);
    }
  }, [scale]);
  return React__default.createElement("div", {
    ref: pdfViewerRef
  });
};

PdfViewer.defaultProps = {
  /**
   * pdf默认缩放比:1.5
   */
  scale: 1.5
};

/**
 * 分页方式显示pdf内容
 * @param props
 * @constructor
 */

var PdfViewerByPage = function PdfViewerByPage(props) {
  var pdfUrl = props.pdfUrl,
      scale = props.scale,
      pageNum = props.pageNum,
      getTotalPage = props.getTotalPage; // 存放pdf文档

  var pdfDocRef = React.useRef(null); // 存放承载pdf画布的dom容器

  var pdfViewerRef = React.useRef(null);
  React.useEffect(function () {
    if (pdfUrl) {
      // 获取pdf文件
      var pdfLoadingTask = PDFJS.getDocument(pdfUrl);
      pdfLoadingTask.promise.then(function (pdfDoc) {
        var pdfViewerDom = pdfViewerRef.current;

        if (pdfDoc && pdfViewerDom) {
          // 缓存pdf内容
          pdfDocRef.current = pdfDoc; // 获取总页数

          var totalPage = pdfDoc.numPages;

          if (getTotalPage) {
            getTotalPage(totalPage);
          }

          if (pageNum <= totalPage) {
            // @ts-ignore
            renderPdfOnePage(pdfViewerDom, pdfDoc, pageNum, scale);
          }
        }
      });
    }
  }, [pdfUrl]);
  React.useLayoutEffect(function () {
    var pdfDoc = pdfDocRef.current;
    var pdfViewerDom = pdfViewerRef.current;

    if (pdfDoc && pdfViewerDom) {
      pdfViewerDom.innerHTML = ''; // @ts-ignore

      renderPdfOnePage(pdfViewerDom, pdfDoc, pageNum, scale);
    }
  }, [pageNum, scale]);
  return React__default.createElement("div", {
    ref: pdfViewerRef
  });
};

PdfViewerByPage.defaultProps = {
  /**
   * 默认渲染第一页
   */
  pageNum: 1,

  /**
   * pdf默认缩放比:1.5
   */
  scale: 1.5
};

exports.PdfViewer = PdfViewer;
exports.PdfViewerByPage = PdfViewerByPage;
//# sourceMappingURL=bp-react-pdf-viewer.cjs.development.js.map
