import React, {FC, useEffect, useLayoutEffect, useRef} from 'react';
import {PdfViewerProps, renderPdfOnePage} from "./PdfViewer";
import {PDFDocumentProxy} from "pdfjs-dist/types/display/api";
import * as PDFJS from "pdfjs-dist";

interface PdfViewerByPageProps extends PdfViewerProps {
    /**
     * 当前显示页号. 页号从1开始. 默认为:1
     */
    pageNum: number;
    /**
     * pdf加载完毕之后,使得外部能够获取到总页数
     * @param totalPage pdf的总页数
     */
    getTotalPage?: (totalPage: number) => void;
}

/**
 * 分页方式显示pdf内容
 * @param props
 * @constructor
 */
const PdfViewerByPage: FC<PdfViewerByPageProps> = (props) => {
    const {pdfUrl, scale, pageNum, getTotalPage} = props;

    // 存放pdf文档
    const pdfDocRef = useRef<PDFDocumentProxy | null>(null);
    // 存放承载pdf画布的dom容器
    const pdfViewerRef = useRef<HTMLDivElement>(null);

    useEffect(() => {
        if (pdfUrl) {
            // 获取pdf文件
            const pdfLoadingTask = PDFJS.getDocument(pdfUrl);
            pdfLoadingTask.promise.then((pdfDoc) => {
                const pdfViewerDom = pdfViewerRef.current;
                if (pdfDoc && pdfViewerDom) {
                    // 缓存pdf内容
                    pdfDocRef.current = pdfDoc;
                    // 获取总页数
                    const totalPage = pdfDoc.numPages;
                    if (getTotalPage) {
                        getTotalPage(totalPage);
                    }
                    if (pageNum <= totalPage) {
                        // @ts-ignore
                        renderPdfOnePage(pdfViewerDom, pdfDoc, pageNum, scale);
                    }
                }
            })
        }
    }, [pdfUrl]);

    useLayoutEffect(() => {
        const pdfDoc = pdfDocRef.current;
        const pdfViewerDom = pdfViewerRef.current;
        if (pdfDoc && pdfViewerDom) {
            pdfViewerDom.innerHTML = '';
            // @ts-ignore
            renderPdfOnePage(pdfViewerDom, pdfDoc, pageNum, scale);
        }
    }, [pageNum, scale])

    return (
        <div ref={pdfViewerRef}>

        </div>
    );
};

PdfViewerByPage.defaultProps = {
    /**
     * 默认渲染第一页
     */
    pageNum: 1,
    /**
     * pdf默认缩放比:1.5
     */
    scale: 1.5
}

export {PdfViewerByPage};
